<?php

/**
 * Classe Wrk
 *
 * Cette classe implémente le worker chargée de récolter les données dans la base de données pour 
 * l'application qui permet de retourner les équipes et les joueurs de hockey.
 *
 * @version 1.0
 * @author Nicolas Rouiller
 * 
 */
class Wrk
{

  /**
   * Constructeur de la classe qui initialise la connexion à la base de données (avec l'objet $pdo).
   */
  function __construct()
  {
    $this->connexion = Connexion::getInstance();
  }

  /**
   * Retourne la liste de toutes les équipes contenues dans la base de données.
   * 
   * @return Array contenant les équipes contenues dans la base de données
   * 
   */
  function getEquipesFromDB()
  {
    $rows = $this->connexion->selectQuery('select * from t_equipe', null);
    $result = array();
    foreach($rows as $row){
      $equipe = new Equipe($row['PK_equipe'], $row['Nom']);
      $result[] = $equipe;
    }
    return $result;
  }

  /**
   * Retourne la liste des joueurs contenus dans la base de données pour une équipe 
   * passée en paramètre.
   * 
   * @param $idEquipe l'ID de l'équipe dont on veut connaître les joueurs.
   * 
   */
  function getJoueursFromDB($idEquipe){
    $rows = $this->connexion->selectQuery('select * from t_joueur where fk_equipe = :equipe', array('equipe'=>$idEquipe));
    $result = array();
    foreach($rows as $row){
      $joueur = new Joueur($row['Nom'], $row['Points']);
      $result[] = $joueur;
    }
    return $result;
  }

  private $connexion;
}
